# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: l2_xpu_infra_mgr.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
import component_pb2 as component__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16l2_xpu_infra_mgr.proto\x12 opi_api.network.evpn_gw.v1alpha1\x1a\x12networktypes.proto\x1a\x0f\x63omponent.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x19google/api/resource.proto\"\xc2\x02\n\rLogicalBridge\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12M\n\x04spec\x18\x02 \x01(\x0b\x32\x33.opi_api.network.evpn_gw.v1alpha1.LogicalBridgeSpecB\x04\xe2\x41\x01\x02R\x04spec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x35.opi_api.network.evpn_gw.v1alpha1.LogicalBridgeStatusB\x04\xe2\x41\x01\x03R\x06status:s\xea\x41p\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridge\x12\x1flogicalBridges/{logical_bridge}*\x0elogicalBridges2\rlogicalBridge\"\xb4\x01\n\x11LogicalBridgeSpec\x12\x1d\n\x07vlan_id\x18\x01 \x01(\rB\x04\xe2\x41\x01\x02R\x06vlanId\x12\x1b\n\x03vni\x18\x02 \x01(\rB\x04\xe2\x41\x01\x01H\x00R\x03vni\x88\x01\x01\x12[\n\x0evtep_ip_prefix\x18\x03 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixB\x04\xe2\x41\x01\x01R\x0cvtepIpPrefixB\x06\n\x04_vni\"\xbf\x01\n\x13LogicalBridgeStatus\x12U\n\x0boper_status\x18\x01 \x01(\x0e\x32..opi_api.network.evpn_gw.v1alpha1.LBOperStatusB\x04\xe2\x41\x01\x03R\noperStatus\x12Q\n\ncomponents\x18\x02 \x03(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.ComponentB\x04\xe2\x41\x01\x03R\ncomponents\"\xac\x01\n\x1a\x43reateLogicalBridgeRequest\x12\x30\n\x11logical_bridge_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01R\x0flogicalBridgeId\x12\\\n\x0elogical_bridge\x18\x02 \x01(\x0b\x32/.opi_api.network.evpn_gw.v1alpha1.LogicalBridgeB\x04\xe2\x41\x01\x02R\rlogicalBridge\"c\n\x19ListLogicalBridgesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x9e\x01\n\x1aListLogicalBridgesResponse\x12X\n\x0flogical_bridges\x18\x01 \x03(\x0b\x32/.opi_api.network.evpn_gw.v1alpha1.LogicalBridgeR\x0elogicalBridges\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"f\n\x17GetLogicalBridgeRequest\x12K\n\x04name\x18\x01 \x01(\tB7\xe2\x41\x01\x02\xfa\x41\x30\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridgeR\x04name\"\x94\x01\n\x1a\x44\x65leteLogicalBridgeRequest\x12K\n\x04name\x18\x01 \x01(\tB7\xe2\x41\x01\x02\xfa\x41\x30\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridgeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xe8\x01\n\x1aUpdateLogicalBridgeRequest\x12\\\n\x0elogical_bridge\x18\x01 \x01(\x0b\x32/.opi_api.network.evpn_gw.v1alpha1.LogicalBridgeB\x04\xe2\x41\x01\x02R\rlogicalBridge\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xaa\x02\n\nBridgePort\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12J\n\x04spec\x18\x02 \x01(\x0b\x32\x30.opi_api.network.evpn_gw.v1alpha1.BridgePortSpecB\x04\xe2\x41\x01\x02R\x04spec\x12P\n\x06status\x18\x03 \x01(\x0b\x32\x32.opi_api.network.evpn_gw.v1alpha1.BridgePortStatusB\x04\xe2\x41\x01\x03R\x06status:d\xea\x41\x61\n+opi_api.network.evpn_gw.v1alpha1/BridgePort\x12\x19\x62ridgePorts/{bridge_port}*\x0b\x62ridgePorts2\nbridgePort\"\xb4\x01\n\x0e\x42ridgePortSpec\x12%\n\x0bmac_address\x18\x01 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\nmacAddress\x12L\n\x05ptype\x18\x02 \x01(\x0e\x32\x30.opi_api.network.evpn_gw.v1alpha1.BridgePortTypeB\x04\xe2\x41\x01\x02R\x05ptype\x12-\n\x0flogical_bridges\x18\x03 \x03(\tB\x04\xe2\x41\x01\x01R\x0elogicalBridges\"\xbc\x01\n\x10\x42ridgePortStatus\x12U\n\x0boper_status\x18\x01 \x01(\x0e\x32..opi_api.network.evpn_gw.v1alpha1.BPOperStatusB\x04\xe2\x41\x01\x03R\noperStatus\x12Q\n\ncomponents\x18\x02 \x03(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.ComponentB\x04\xe2\x41\x01\x03R\ncomponents\"\x9a\x01\n\x17\x43reateBridgePortRequest\x12*\n\x0e\x62ridge_port_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01R\x0c\x62ridgePortId\x12S\n\x0b\x62ridge_port\x18\x02 \x01(\x0b\x32,.opi_api.network.evpn_gw.v1alpha1.BridgePortB\x04\xe2\x41\x01\x02R\nbridgePort\"`\n\x16ListBridgePortsRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x92\x01\n\x17ListBridgePortsResponse\x12O\n\x0c\x62ridge_ports\x18\x01 \x03(\x0b\x32,.opi_api.network.evpn_gw.v1alpha1.BridgePortR\x0b\x62ridgePorts\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"`\n\x14GetBridgePortRequest\x12H\n\x04name\x18\x01 \x01(\tB4\xe2\x41\x01\x02\xfa\x41-\n+opi_api.network.evpn_gw.v1alpha1/BridgePortR\x04name\"\x8e\x01\n\x17\x44\x65leteBridgePortRequest\x12H\n\x04name\x18\x01 \x01(\tB4\xe2\x41\x01\x02\xfa\x41-\n+opi_api.network.evpn_gw.v1alpha1/BridgePortR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xdc\x01\n\x17UpdateBridgePortRequest\x12S\n\x0b\x62ridge_port\x18\x01 \x01(\x0b\x32,.opi_api.network.evpn_gw.v1alpha1.BridgePortB\x04\xe2\x41\x01\x02R\nbridgePort\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing*\x80\x01\n\x0cLBOperStatus\x12\x1e\n\x1aLB_OPER_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11LB_OPER_STATUS_UP\x10\x01\x12\x17\n\x13LB_OPER_STATUS_DOWN\x10\x02\x12 \n\x1cLB_OPER_STATUS_TO_BE_DELETED\x10\x03*\x80\x01\n\x0c\x42POperStatus\x12\x1e\n\x1a\x42P_OPER_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11\x42P_OPER_STATUS_UP\x10\x01\x12\x17\n\x13\x42P_OPER_STATUS_DOWN\x10\x02\x12 \n\x1c\x42P_OPER_STATUS_TO_BE_DELETED\x10\x03*k\n\x0e\x42ridgePortType\x12 \n\x1c\x42RIDGE_PORT_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x42RIDGE_PORT_TYPE_ACCESS\x10\x01\x12\x1a\n\x16\x42RIDGE_PORT_TYPE_TRUNK\x10\x02\x32\xc9\x07\n\x14LogicalBridgeService\x12\xd3\x01\n\x13\x43reateLogicalBridge\x12<.opi_api.network.evpn_gw.v1alpha1.CreateLogicalBridgeRequest\x1a/.opi_api.network.evpn_gw.v1alpha1.LogicalBridge\"M\xda\x41 logical_bridge,logical_bridge_id\x82\xd3\xe4\x93\x02$\"\x12/v1/logicalBridges:\x0elogical_bridge\x12\xab\x01\n\x12ListLogicalBridges\x12;.opi_api.network.evpn_gw.v1alpha1.ListLogicalBridgesRequest\x1a<.opi_api.network.evpn_gw.v1alpha1.ListLogicalBridgesResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/logicalBridges\x12\xaa\x01\n\x10GetLogicalBridge\x12\x39.opi_api.network.evpn_gw.v1alpha1.GetLogicalBridgeRequest\x1a/.opi_api.network.evpn_gw.v1alpha1.LogicalBridge\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=logicalBridges/*}\x12\x97\x01\n\x13\x44\x65leteLogicalBridge\x12<.opi_api.network.evpn_gw.v1alpha1.DeleteLogicalBridgeRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=logicalBridges/*}\x12\xe5\x01\n\x13UpdateLogicalBridge\x12<.opi_api.network.evpn_gw.v1alpha1.UpdateLogicalBridgeRequest\x1a/.opi_api.network.evpn_gw.v1alpha1.LogicalBridge\"_\xda\x41\x1alogical_bridge,update_mask\x82\xd3\xe4\x93\x02<2*/v1/{logical_bridge.name=logicalBridges/*}:\x0elogical_bridge2\xfb\x06\n\x11\x42ridgePortService\x12\xbe\x01\n\x10\x43reateBridgePort\x12\x39.opi_api.network.evpn_gw.v1alpha1.CreateBridgePortRequest\x1a,.opi_api.network.evpn_gw.v1alpha1.BridgePort\"A\xda\x41\x1a\x62ridge_port,bridge_port_id\x82\xd3\xe4\x93\x02\x1e\"\x0f/v1/bridgePorts:\x0b\x62ridge_port\x12\x9f\x01\n\x0fListBridgePorts\x12\x38.opi_api.network.evpn_gw.v1alpha1.ListBridgePortsRequest\x1a\x39.opi_api.network.evpn_gw.v1alpha1.ListBridgePortsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/bridgePorts\x12\x9e\x01\n\rGetBridgePort\x12\x36.opi_api.network.evpn_gw.v1alpha1.GetBridgePortRequest\x1a,.opi_api.network.evpn_gw.v1alpha1.BridgePort\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{name=bridgePorts/*}\x12\x8e\x01\n\x10\x44\x65leteBridgePort\x12\x39.opi_api.network.evpn_gw.v1alpha1.DeleteBridgePortRequest\x1a\x16.google.protobuf.Empty\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a*\x18/v1/{name=bridgePorts/*}\x12\xd0\x01\n\x10UpdateBridgePort\x12\x39.opi_api.network.evpn_gw.v1alpha1.UpdateBridgePortRequest\x1a,.opi_api.network.evpn_gw.v1alpha1.BridgePort\"S\xda\x41\x17\x62ridge_port,update_mask\x82\xd3\xe4\x93\x02\x33\x32$/v1/{bridge_port.name=bridgePorts/*}:\x0b\x62ridge_portBw\n opi_api.network.evpn_gw.v1alpha1B\x12L2XpuInfraMgrProtoP\x01Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'l2_xpu_infra_mgr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n opi_api.network.evpn_gw.v1alpha1B\022L2XpuInfraMgrProtoP\001Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/go'
  _globals['_LOGICALBRIDGE'].fields_by_name['name']._options = None
  _globals['_LOGICALBRIDGE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_LOGICALBRIDGE'].fields_by_name['spec']._options = None
  _globals['_LOGICALBRIDGE'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_LOGICALBRIDGE'].fields_by_name['status']._options = None
  _globals['_LOGICALBRIDGE'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_LOGICALBRIDGE']._options = None
  _globals['_LOGICALBRIDGE']._serialized_options = b'\352Ap\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridge\022\037logicalBridges/{logical_bridge}*\016logicalBridges2\rlogicalBridge'
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vlan_id']._options = None
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vlan_id']._serialized_options = b'\342A\001\002'
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vni']._options = None
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vni']._serialized_options = b'\342A\001\001'
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vtep_ip_prefix']._options = None
  _globals['_LOGICALBRIDGESPEC'].fields_by_name['vtep_ip_prefix']._serialized_options = b'\342A\001\001'
  _globals['_LOGICALBRIDGESTATUS'].fields_by_name['oper_status']._options = None
  _globals['_LOGICALBRIDGESTATUS'].fields_by_name['oper_status']._serialized_options = b'\342A\001\003'
  _globals['_LOGICALBRIDGESTATUS'].fields_by_name['components']._options = None
  _globals['_LOGICALBRIDGESTATUS'].fields_by_name['components']._serialized_options = b'\342A\001\003'
  _globals['_CREATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge_id']._options = None
  _globals['_CREATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge']._options = None
  _globals['_CREATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge']._serialized_options = b'\342A\001\002'
  _globals['_LISTLOGICALBRIDGESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTLOGICALBRIDGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTLOGICALBRIDGESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTLOGICALBRIDGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETLOGICALBRIDGEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETLOGICALBRIDGEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A0\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridge'
  _globals['_DELETELOGICALBRIDGEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETELOGICALBRIDGEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A0\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridge'
  _globals['_DELETELOGICALBRIDGEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETELOGICALBRIDGEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge']._options = None
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['logical_bridge']._serialized_options = b'\342A\001\002'
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATELOGICALBRIDGEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_BRIDGEPORT'].fields_by_name['name']._options = None
  _globals['_BRIDGEPORT'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_BRIDGEPORT'].fields_by_name['spec']._options = None
  _globals['_BRIDGEPORT'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_BRIDGEPORT'].fields_by_name['status']._options = None
  _globals['_BRIDGEPORT'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_BRIDGEPORT']._options = None
  _globals['_BRIDGEPORT']._serialized_options = b'\352Aa\n+opi_api.network.evpn_gw.v1alpha1/BridgePort\022\031bridgePorts/{bridge_port}*\013bridgePorts2\nbridgePort'
  _globals['_BRIDGEPORTSPEC'].fields_by_name['mac_address']._options = None
  _globals['_BRIDGEPORTSPEC'].fields_by_name['mac_address']._serialized_options = b'\342A\001\002'
  _globals['_BRIDGEPORTSPEC'].fields_by_name['ptype']._options = None
  _globals['_BRIDGEPORTSPEC'].fields_by_name['ptype']._serialized_options = b'\342A\001\002'
  _globals['_BRIDGEPORTSPEC'].fields_by_name['logical_bridges']._options = None
  _globals['_BRIDGEPORTSPEC'].fields_by_name['logical_bridges']._serialized_options = b'\342A\001\001'
  _globals['_BRIDGEPORTSTATUS'].fields_by_name['oper_status']._options = None
  _globals['_BRIDGEPORTSTATUS'].fields_by_name['oper_status']._serialized_options = b'\342A\001\003'
  _globals['_BRIDGEPORTSTATUS'].fields_by_name['components']._options = None
  _globals['_BRIDGEPORTSTATUS'].fields_by_name['components']._serialized_options = b'\342A\001\003'
  _globals['_CREATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port_id']._options = None
  _globals['_CREATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port']._options = None
  _globals['_CREATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port']._serialized_options = b'\342A\001\002'
  _globals['_LISTBRIDGEPORTSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTBRIDGEPORTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTBRIDGEPORTSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTBRIDGEPORTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETBRIDGEPORTREQUEST'].fields_by_name['name']._options = None
  _globals['_GETBRIDGEPORTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A-\n+opi_api.network.evpn_gw.v1alpha1/BridgePort'
  _globals['_DELETEBRIDGEPORTREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEBRIDGEPORTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A-\n+opi_api.network.evpn_gw.v1alpha1/BridgePort'
  _globals['_DELETEBRIDGEPORTREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEBRIDGEPORTREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port']._options = None
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['bridge_port']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEBRIDGEPORTREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['CreateLogicalBridge']._options = None
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['CreateLogicalBridge']._serialized_options = b'\332A logical_bridge,logical_bridge_id\202\323\344\223\002$\"\022/v1/logicalBridges:\016logical_bridge'
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['ListLogicalBridges']._options = None
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['ListLogicalBridges']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/logicalBridges'
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['GetLogicalBridge']._options = None
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['GetLogicalBridge']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=logicalBridges/*}'
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['DeleteLogicalBridge']._options = None
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['DeleteLogicalBridge']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=logicalBridges/*}'
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['UpdateLogicalBridge']._options = None
  _globals['_LOGICALBRIDGESERVICE'].methods_by_name['UpdateLogicalBridge']._serialized_options = b'\332A\032logical_bridge,update_mask\202\323\344\223\002<2*/v1/{logical_bridge.name=logicalBridges/*}:\016logical_bridge'
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['CreateBridgePort']._options = None
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['CreateBridgePort']._serialized_options = b'\332A\032bridge_port,bridge_port_id\202\323\344\223\002\036\"\017/v1/bridgePorts:\013bridge_port'
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['ListBridgePorts']._options = None
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['ListBridgePorts']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/bridgePorts'
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['GetBridgePort']._options = None
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['GetBridgePort']._serialized_options = b'\332A\004name\202\323\344\223\002\032\022\030/v1/{name=bridgePorts/*}'
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['DeleteBridgePort']._options = None
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['DeleteBridgePort']._serialized_options = b'\332A\004name\202\323\344\223\002\032*\030/v1/{name=bridgePorts/*}'
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['UpdateBridgePort']._options = None
  _globals['_BRIDGEPORTSERVICE'].methods_by_name['UpdateBridgePort']._serialized_options = b'\332A\027bridge_port,update_mask\202\323\344\223\00232$/v1/{bridge_port.name=bridgePorts/*}:\013bridge_port'
  _globals['_LBOPERSTATUS']._serialized_start=3450
  _globals['_LBOPERSTATUS']._serialized_end=3578
  _globals['_BPOPERSTATUS']._serialized_start=3581
  _globals['_BPOPERSTATUS']._serialized_end=3709
  _globals['_BRIDGEPORTTYPE']._serialized_start=3711
  _globals['_BRIDGEPORTTYPE']._serialized_end=3818
  _globals['_LOGICALBRIDGE']._serialized_start=276
  _globals['_LOGICALBRIDGE']._serialized_end=598
  _globals['_LOGICALBRIDGESPEC']._serialized_start=601
  _globals['_LOGICALBRIDGESPEC']._serialized_end=781
  _globals['_LOGICALBRIDGESTATUS']._serialized_start=784
  _globals['_LOGICALBRIDGESTATUS']._serialized_end=975
  _globals['_CREATELOGICALBRIDGEREQUEST']._serialized_start=978
  _globals['_CREATELOGICALBRIDGEREQUEST']._serialized_end=1150
  _globals['_LISTLOGICALBRIDGESREQUEST']._serialized_start=1152
  _globals['_LISTLOGICALBRIDGESREQUEST']._serialized_end=1251
  _globals['_LISTLOGICALBRIDGESRESPONSE']._serialized_start=1254
  _globals['_LISTLOGICALBRIDGESRESPONSE']._serialized_end=1412
  _globals['_GETLOGICALBRIDGEREQUEST']._serialized_start=1414
  _globals['_GETLOGICALBRIDGEREQUEST']._serialized_end=1516
  _globals['_DELETELOGICALBRIDGEREQUEST']._serialized_start=1519
  _globals['_DELETELOGICALBRIDGEREQUEST']._serialized_end=1667
  _globals['_UPDATELOGICALBRIDGEREQUEST']._serialized_start=1670
  _globals['_UPDATELOGICALBRIDGEREQUEST']._serialized_end=1902
  _globals['_BRIDGEPORT']._serialized_start=1905
  _globals['_BRIDGEPORT']._serialized_end=2203
  _globals['_BRIDGEPORTSPEC']._serialized_start=2206
  _globals['_BRIDGEPORTSPEC']._serialized_end=2386
  _globals['_BRIDGEPORTSTATUS']._serialized_start=2389
  _globals['_BRIDGEPORTSTATUS']._serialized_end=2577
  _globals['_CREATEBRIDGEPORTREQUEST']._serialized_start=2580
  _globals['_CREATEBRIDGEPORTREQUEST']._serialized_end=2734
  _globals['_LISTBRIDGEPORTSREQUEST']._serialized_start=2736
  _globals['_LISTBRIDGEPORTSREQUEST']._serialized_end=2832
  _globals['_LISTBRIDGEPORTSRESPONSE']._serialized_start=2835
  _globals['_LISTBRIDGEPORTSRESPONSE']._serialized_end=2981
  _globals['_GETBRIDGEPORTREQUEST']._serialized_start=2983
  _globals['_GETBRIDGEPORTREQUEST']._serialized_end=3079
  _globals['_DELETEBRIDGEPORTREQUEST']._serialized_start=3082
  _globals['_DELETEBRIDGEPORTREQUEST']._serialized_end=3224
  _globals['_UPDATEBRIDGEPORTREQUEST']._serialized_start=3227
  _globals['_UPDATEBRIDGEPORTREQUEST']._serialized_end=3447
  _globals['_LOGICALBRIDGESERVICE']._serialized_start=3821
  _globals['_LOGICALBRIDGESERVICE']._serialized_end=4790
  _globals['_BRIDGEPORTSERVICE']._serialized_start=4793
  _globals['_BRIDGEPORTSERVICE']._serialized_end=5684
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: subnet.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csubnet.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xe0\x01\n\x06Subnet\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12>\n\x04spec\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.SubnetSpecR\x04spec\x12\x44\n\x06status\x18\x03 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.SubnetStatusR\x06status:<\xea\x41\x39\n%opi_api.network.cloud.v1alpha1/subnet\x12\x10subnets/{subnet}\"\xc2\t\n\nSubnetSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12N\n\tv4_prefix\x18\x02 \x01(\x0b\x32\x31.opi_api.network.opinetcommon.v1alpha1.IPv4PrefixR\x08v4Prefix\x12N\n\tv6_prefix\x18\x03 \x01(\x0b\x32\x31.opi_api.network.opinetcommon.v1alpha1.IPv6PrefixR\x08v6Prefix\x12\x33\n\x16ipv4_virtual_router_ip\x18\x04 \x01(\rR\x13ipv4VirtualRouterIp\x12\x33\n\x16ipv6_virtual_router_ip\x18\x05 \x01(\x0cR\x13ipv6VirtualRouterIp\x12,\n\x12virtual_router_mac\x18\x06 \x01(\x0cR\x10virtualRouterMac\x12\x34\n\x17v4_route_table_name_ref\x18\x07 \x01(\tR\x13v4RouteTableNameRef\x12\x34\n\x17v6_route_table_name_ref\x18\x08 \x01(\tR\x13v6RouteTableNameRef\x12I\n\"ingess_v4_security_policy_name_ref\x18\t \x03(\tR\x1dingessV4SecurityPolicyNameRef\x12K\n#ingress_v6_security_policy_name_ref\x18\n \x03(\tR\x1eingressV6SecurityPolicyNameRef\x12I\n\"egress_v4_security_policy_name_ref\x18\x0b \x03(\tR\x1d\x65gressV4SecurityPolicyNameRef\x12I\n\"egress_v6_security_policy_name_ref\x18\x0c \x03(\tR\x1d\x65gressV6SecurityPolicyNameRef\x12O\n\x0c\x61\x63\x63\x65ss_encap\x18\r \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x0b\x61\x63\x63\x65ssEncap\x12O\n\x0c\x66\x61\x62ric_encap\x18\x0e \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x0b\x66\x61\x62ricEncap\x12\x35\n\x17host_interface_name_ref\x18\x0f \x03(\tR\x14hostInterfaceNameRef\x12\x10\n\x03tos\x18\x10 \x01(\x05R\x03tos\x12\x1c\n\tconnected\x18\x11 \x01(\x08R\tconnected\x12I\n\"ingress_default_sg_policy_name_ref\x18\x12 \x01(\tR\x1dingressDefaultSgPolicyNameRef\x12G\n!egress_default_sg_policy_name_ref\x18\x13 \x01(\tR\x1c\x65gressDefaultSgPolicyNameRef\x12#\n\rremote_subnet\x18\x14 \x01(\x08R\x0cremoteSubnet\"H\n\x0cSubnetStatus\x12\x19\n\x08hw_index\x18\x01 \x01(\x05R\x07hwIndex\x12\x1d\n\nvnic_count\x18\x02 \x01(\x05R\tvnicCountBl\n\x1eopi_api.network.cloud.v1alpha1B\x0bSubnetProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'subnet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\013SubnetProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_SUBNET']._options = None
  _globals['_SUBNET']._serialized_options = b'\352A9\n%opi_api.network.cloud.v1alpha1/subnet\022\020subnets/{subnet}'
  _globals['_SUBNET']._serialized_start=96
  _globals['_SUBNET']._serialized_end=320
  _globals['_SUBNETSPEC']._serialized_start=323
  _globals['_SUBNETSPEC']._serialized_end=1541
  _globals['_SUBNETSTATUS']._serialized_start=1543
  _globals['_SUBNETSTATUS']._serialized_end=1615
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: port.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nport.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/api/resource.proto\"\xd4\x01\n\x04Port\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12<\n\x04spec\x18\x02 \x01(\x0b\x32(.opi_api.network.cloud.v1alpha1.PortSpecR\x04spec\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.PortStatusR\x06status:6\xea\x41\x33\n#opi_api.network.cloud.v1alpha1/port\x12\x0cports/{port}\"\xad\x05\n\x08PortSpec\x12\x1f\n\x0bport_number\x18\x01 \x01(\x05R\nportNumber\x12O\n\x0b\x61\x64min_state\x18\x02 \x01(\x0e\x32..opi_api.network.cloud.v1alpha1.PortAdminStateR\nadminState\x12<\n\x04type\x18\x03 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.PortTypeR\x04type\x12?\n\x05speed\x18\x04 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.PortSpeedR\x05speed\x12\x46\n\x08\x66\x65\x63_type\x18\x05 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.PortFecTypeR\x07\x66\x65\x63Type\x12%\n\x0e\x61utoneg_enable\x18\x06 \x01(\x08R\rautonegEnable\x12)\n\x10\x64\x65\x62ounce_timeout\x18\x07 \x01(\x05R\x0f\x64\x65\x62ounceTimeout\x12\x10\n\x03mtu\x18\x08 \x01(\x05R\x03mtu\x12L\n\npause_type\x18\t \x01(\x0e\x32-.opi_api.network.cloud.v1alpha1.PortPauseTypeR\tpauseType\x12\x1e\n\x0btx_pause_en\x18\n \x01(\x08R\ttxPauseEn\x12\x1e\n\x0brx_pause_en\x18\x0b \x01(\x08R\trxPauseEn\x12U\n\rloopback_mode\x18\x0c \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.PortLoopBackModeR\x0cloopbackMode\x12\x1f\n\x0blanes_count\x18\r \x01(\x05R\nlanesCount\"\x93\x03\n\nPortStatus\x12\x19\n\x08if_index\x18\x01 \x01(\rR\x07ifIndex\x12O\n\x0blink_status\x18\x02 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.PortLinkStatusR\nlinkStatus\x12O\n\x0bxcvr_status\x18\x03 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.PortXcvrStatusR\nxcvrStatus\x12H\n\tfsm_state\x18\x04 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.PortLinkFSMR\x08\x66smState\x12\x15\n\x06mac_id\x18\x05 \x01(\x05R\x05macId\x12\x15\n\x06mac_ch\x18\x06 \x01(\x05R\x05macCh\x12P\n\nfsm_record\x18\x07 \x03(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.PortLinkFSMRecordR\tfsmRecord\"\xb0\x02\n\x0ePortLinkStatus\x12L\n\noper_state\x18\x01 \x01(\x0e\x32-.opi_api.network.cloud.v1alpha1.PortOperStateR\toperState\x12H\n\nport_speed\x18\x02 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.PortSpeedR\tportSpeed\x12\x1d\n\nautoneg_en\x18\x03 \x01(\x08R\tautonegEn\x12\x1f\n\x0blanes_count\x18\x04 \x01(\x05R\nlanesCount\x12\x46\n\x08\x66\x65\x63_type\x18\x05 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.PortFecTypeR\x07\x66\x65\x63Type\"\xd1\x04\n\x0ePortXcvrStatus\x12\x12\n\x04port\x18\x01 \x01(\x05R\x04port\x12\x43\n\x05state\x18\x02 \x01(\x0e\x32-.opi_api.network.cloud.v1alpha1.PortXcvrStateR\x05state\x12=\n\x03pid\x18\x03 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.PortXcvrPidR\x03pid\x12H\n\nmedia_type\x18\x04 \x01(\x0e\x32).opi_api.network.cloud.v1alpha1.MediaTypeR\tmediaType\x12\x1d\n\nxcvr_sprom\x18\x05 \x01(\x0cR\txcvrSprom\x12\x1e\n\nvendorname\x18\x06 \x01(\tR\nvendorname\x12\x1d\n\nvendor_oui\x18\x07 \x01(\tR\tvendorOui\x12#\n\rencoding_type\x18\x08 \x01(\x05R\x0c\x65ncodingType\x12#\n\rserial_number\x18\t \x01(\tR\x0cserialNumber\x12\x1f\n\x0bpart_number\x18\n \x01(\tR\npartNumber\x12\x1a\n\x08revision\x18\x0b \x01(\tR\x08revision\x12 \n\x0btemperature\x18\x0c \x01(\x05R\x0btemperature\x12)\n\x10warn_temperature\x18\r \x01(\x05R\x0fwarnTemperature\x12+\n\x11\x61larm_temperature\x18\x0e \x01(\x05R\x10\x61larmTemperature\"\xb4\x01\n\x11PortLinkFSMRecord\x12H\n\tfsm_state\x18\x01 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.PortLinkFSMR\x08\x66smState\x12\x39\n\nstate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstateTime\x12\x1a\n\x08\x64uration\x18\x03 \x01(\tR\x08\x64uration*f\n\x0ePortAdminState\x12 \n\x1cPORT_ADMIN_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15PORT_ADMIN_STATE_DOWN\x10\x01\x12\x17\n\x13PORT_ADMIN_STATE_UP\x10\x02*\xaf\x01\n\rPortXcvrState\x12\x1f\n\x1bPORT_XCVR_STATE_UNSPECIFIED\x10\x00\x12\x1c\n\x18PORT_XCVR_STATE_INSERTED\x10\x01\x12\x1b\n\x17PORT_XCVR_STATE_PENDING\x10\x02\x12\x1e\n\x1aPORT_XCVR_STATE_SPROM_READ\x10\x03\x12\"\n\x1ePORT_XCVR_STATE_SPROM_READ_ERR\x10\x04*\xf8\x08\n\x0bPortXcvrPid\x12\x1d\n\x19PORT_XCVR_PID_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_CR4\x10\x01\x12\"\n\x1ePORT_XCVR_PID_QSFP_40GBASE_CR4\x10\x02\x12\"\n\x1ePORT_XCVR_PID_SFP_25GBASE_CR_S\x10\x03\x12\"\n\x1ePORT_XCVR_PID_SFP_25GBASE_CR_L\x10\x04\x12\"\n\x1ePORT_XCVR_PID_SFP_25GBASE_CR_N\x10\x05\x12!\n\x1dPORT_XCVR_PID_QSFP_50G_CR2_FC\x10\x06\x12\x1e\n\x1aPORT_XCVR_PID_QSFP_50G_CR2\x10\x07\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_200G_CR4\x10\x08\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_AOC\x10\x32\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_ACC\x10\x33\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_SR4\x10\x34\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_LR4\x10\x35\x12\x1f\n\x1bPORT_XCVR_PID_QSFP_100G_ER4\x10\x36\x12\"\n\x1ePORT_XCVR_PID_QSFP_40GBASE_ER4\x10\x37\x12\"\n\x1ePORT_XCVR_PID_QSFP_40GBASE_SR4\x10\x38\x12\"\n\x1ePORT_XCVR_PID_QSFP_40GBASE_LR4\x10\x39\x12\"\n\x1ePORT_XCVR_PID_QSFP_40GBASE_AOC\x10:\x12 \n\x1cPORT_XCVR_PID_SFP_25GBASE_SR\x10;\x12 \n\x1cPORT_XCVR_PID_SFP_25GBASE_LR\x10<\x12 \n\x1cPORT_XCVR_PID_SFP_25GBASE_ER\x10=\x12!\n\x1dPORT_XCVR_PID_SFP_25GBASE_AOC\x10>\x12 \n\x1cPORT_XCVR_PID_SFP_10GBASE_SR\x10?\x12 \n\x1cPORT_XCVR_PID_SFP_10GBASE_LR\x10@\x12!\n\x1dPORT_XCVR_PID_SFP_10GBASE_LRM\x10\x41\x12 \n\x1cPORT_XCVR_PID_SFP_10GBASE_ER\x10\x42\x12!\n\x1dPORT_XCVR_PID_SFP_10GBASE_AOC\x10\x43\x12 \n\x1cPORT_XCVR_PID_SFP_10GBASE_CU\x10\x44\x12!\n\x1dPORT_XCVR_PID_QSFP_100G_CWDM4\x10\x45\x12 \n\x1cPORT_XCVR_PID_QSFP_100G_PSM4\x10\x46\x12!\n\x1dPORT_XCVR_PID_SFP_25GBASE_ACC\x10G\x12\x1f\n\x1bPORT_XCVR_PID_SFP_10GBASE_T\x10H\x12 \n\x1cPORT_XCVR_PID_SFP_1000BASE_T\x10I*T\n\tMediaType\x12\x1a\n\x16MEDIA_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MEDIA_TYPE_COPPER\x10\x01\x12\x14\n\x10MEDIA_TYPE_FIBER\x10\x02*b\n\rPortOperState\x12\x1f\n\x1bPORT_OPER_STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12PORT_OPER_STATE_UP\x10\x01\x12\x18\n\x14PORT_OPER_STATE_DOWN\x10\x02*c\n\rPortPauseType\x12\x1f\n\x1bPORT_PAUSE_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14PORT_PAUSE_TYPE_LINK\x10\x01\x12\x17\n\x13PORT_PAUSE_TYPE_PFC\x10\x02*\xb6\x06\n\x0bPortLinkFSM\x12\x1d\n\x19PORT_LINK_FSM_UNSPECIFIED\x10\x00\x12\x19\n\x15PORT_LINK_FSM_ENABLED\x10\x01\x12\x18\n\x14PORT_LINK_FSM_AN_CFG\x10\x02\x12\x1d\n\x19PORT_LINK_FSM_AN_DISABLED\x10\x03\x12\x1a\n\x16PORT_LINK_FSM_AN_START\x10\x04\x12\"\n\x1ePORT_LINK_FSM_AN_SIGNAL_DETECT\x10\x05\x12\x1d\n\x19PORT_LINK_FSM_AN_WAIT_HCD\x10\x06\x12\x1d\n\x19PORT_LINK_FSM_AN_COMPLETE\x10\x07\x12\x1c\n\x18PORT_LINK_FSM_SERDES_CFG\x10\x08\x12!\n\x1dPORT_LINK_FSM_WAIT_SERDES_RDY\x10\t\x12\x19\n\x15PORT_LINK_FSM_MAC_CFG\x10\n\x12\x1f\n\x1bPORT_LINK_FSM_SIGNAL_DETECT\x10\x0b\x12\x1f\n\x1bPORT_LINK_FSM_AN_DFE_TUNING\x10\x0c\x12\x1c\n\x18PORT_LINK_FSM_DFE_TUNING\x10\r\x12\x1e\n\x1aPORT_LINK_FSM_DFE_DISABLED\x10\x0e\x12 \n\x1cPORT_LINK_FSM_DFE_START_ICAL\x10\x0f\x12\x1f\n\x1bPORT_LINK_FSM_DFE_WAIT_ICAL\x10\x10\x12 \n\x1cPORT_LINK_FSM_DFE_START_PCAL\x10\x11\x12\x1f\n\x1bPORT_LINK_FSM_DFE_WAIT_PCAL\x10\x12\x12%\n!PORT_LINK_FSM_DFE_PCAL_CONTINUOUS\x10\x13\x12)\n%PORT_LINK_FSM_CLEAR_MAC_REMOTE_FAULTS\x10\x14\x12\x1f\n\x1bPORT_LINK_FSM_WAIT_MAC_SYNC\x10\x15\x12\'\n#PORT_LINK_FSM_WAIT_MAC_FAULTS_CLEAR\x10\x16\x12\"\n\x1ePORT_LINK_FSM_WAIT_PHY_LINK_UP\x10\x17\x12\x14\n\x10PORT_LINK_FSM_UP\x10\x18*q\n\x10PortLoopBackMode\x12#\n\x1fPORT_LOOP_BACK_MODE_UNSPECIFIED\x10\x00\x12\x1b\n\x17PORT_LOOP_BACK_MODE_MAC\x10\x01\x12\x1b\n\x17PORT_LOOP_BACK_MODE_PHY\x10\x02*X\n\x0bPortFecType\x12\x1d\n\x19PORT_FEC_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10PORT_FEC_TYPE_FC\x10\x01\x12\x14\n\x10PORT_FEC_TYPE_RS\x10\x02*P\n\x08PortType\x12\x19\n\x15PORT_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rPORT_TYPE_ETH\x10\x01\x12\x16\n\x12PORT_TYPE_ETH_MGMT\x10\x02*\xf2\x01\n\tPortSpeed\x12\x1a\n\x16PORT_SPEED_UNSPECIFIED\x10\x00\x12\x12\n\x0ePORT_SPEED_10M\x10\x01\x12\x13\n\x0fPORT_SPEED_100M\x10\x02\x12\x11\n\rPORT_SPEED_1G\x10\x03\x12\x12\n\x0ePORT_SPEED_10G\x10\x04\x12\x12\n\x0ePORT_SPEED_25G\x10\x05\x12\x12\n\x0ePORT_SPEED_40G\x10\x06\x12\x12\n\x0ePORT_SPEED_50G\x10\x07\x12\x13\n\x0fPORT_SPEED_100G\x10\x08\x12\x13\n\x0fPORT_SPEED_200G\x10\t\x12\x13\n\x0fPORT_SPEED_400G\x10\nBj\n\x1eopi_api.network.cloud.v1alpha1B\tPortProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'port_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\tPortProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_PORT']._options = None
  _globals['_PORT']._serialized_options = b'\352A3\n#opi_api.network.cloud.v1alpha1/port\022\014ports/{port}'
  _globals['_PORTADMINSTATE']._serialized_start=2501
  _globals['_PORTADMINSTATE']._serialized_end=2603
  _globals['_PORTXCVRSTATE']._serialized_start=2606
  _globals['_PORTXCVRSTATE']._serialized_end=2781
  _globals['_PORTXCVRPID']._serialized_start=2784
  _globals['_PORTXCVRPID']._serialized_end=3928
  _globals['_MEDIATYPE']._serialized_start=3930
  _globals['_MEDIATYPE']._serialized_end=4014
  _globals['_PORTOPERSTATE']._serialized_start=4016
  _globals['_PORTOPERSTATE']._serialized_end=4114
  _globals['_PORTPAUSETYPE']._serialized_start=4116
  _globals['_PORTPAUSETYPE']._serialized_end=4215
  _globals['_PORTLINKFSM']._serialized_start=4218
  _globals['_PORTLINKFSM']._serialized_end=5040
  _globals['_PORTLOOPBACKMODE']._serialized_start=5042
  _globals['_PORTLOOPBACKMODE']._serialized_end=5155
  _globals['_PORTFECTYPE']._serialized_start=5157
  _globals['_PORTFECTYPE']._serialized_end=5245
  _globals['_PORTTYPE']._serialized_start=5247
  _globals['_PORTTYPE']._serialized_end=5327
  _globals['_PORTSPEED']._serialized_start=5330
  _globals['_PORTSPEED']._serialized_end=5572
  _globals['_PORT']._serialized_start=107
  _globals['_PORT']._serialized_end=319
  _globals['_PORTSPEC']._serialized_start=322
  _globals['_PORTSPEC']._serialized_end=1007
  _globals['_PORTSTATUS']._serialized_start=1010
  _globals['_PORTSTATUS']._serialized_end=1413
  _globals['_PORTLINKSTATUS']._serialized_start=1416
  _globals['_PORTLINKSTATUS']._serialized_end=1720
  _globals['_PORTXCVRSTATUS']._serialized_start=1723
  _globals['_PORTXCVRSTATUS']._serialized_end=2316
  _globals['_PORTLINKFSMRECORD']._serialized_start=2319
  _globals['_PORTLINKFSMRECORD']._serialized_end=2499
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_aio_pb2 as backend__aio__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AioVolumeServiceStub(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAioVolume = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/CreateAioVolume',
                request_serializer=backend__aio__pb2.CreateAioVolumeRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioVolume.FromString,
                )
        self.DeleteAioVolume = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/DeleteAioVolume',
                request_serializer=backend__aio__pb2.DeleteAioVolumeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateAioVolume = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/UpdateAioVolume',
                request_serializer=backend__aio__pb2.UpdateAioVolumeRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioVolume.FromString,
                )
        self.ListAioVolumes = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/ListAioVolumes',
                request_serializer=backend__aio__pb2.ListAioVolumesRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.ListAioVolumesResponse.FromString,
                )
        self.GetAioVolume = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/GetAioVolume',
                request_serializer=backend__aio__pb2.GetAioVolumeRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioVolume.FromString,
                )
        self.StatsAioVolume = channel.unary_unary(
                '/opi_api.storage.v1.AioVolumeService/StatsAioVolume',
                request_serializer=backend__aio__pb2.StatsAioVolumeRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.StatsAioVolumeResponse.FromString,
                )


class AioVolumeServiceServicer(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    def CreateAioVolume(self, request, context):
        """Create an Aio Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAioVolume(self, request, context):
        """Delete an Aio Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAioVolume(self, request, context):
        """Update an Aio Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAioVolumes(self, request, context):
        """List Aio Volumes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAioVolume(self, request, context):
        """Get an Aio Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsAioVolume(self, request, context):
        """Get an Aio Volume statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AioVolumeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAioVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAioVolume,
                    request_deserializer=backend__aio__pb2.CreateAioVolumeRequest.FromString,
                    response_serializer=backend__aio__pb2.AioVolume.SerializeToString,
            ),
            'DeleteAioVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAioVolume,
                    request_deserializer=backend__aio__pb2.DeleteAioVolumeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateAioVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAioVolume,
                    request_deserializer=backend__aio__pb2.UpdateAioVolumeRequest.FromString,
                    response_serializer=backend__aio__pb2.AioVolume.SerializeToString,
            ),
            'ListAioVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAioVolumes,
                    request_deserializer=backend__aio__pb2.ListAioVolumesRequest.FromString,
                    response_serializer=backend__aio__pb2.ListAioVolumesResponse.SerializeToString,
            ),
            'GetAioVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAioVolume,
                    request_deserializer=backend__aio__pb2.GetAioVolumeRequest.FromString,
                    response_serializer=backend__aio__pb2.AioVolume.SerializeToString,
            ),
            'StatsAioVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsAioVolume,
                    request_deserializer=backend__aio__pb2.StatsAioVolumeRequest.FromString,
                    response_serializer=backend__aio__pb2.StatsAioVolumeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.AioVolumeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AioVolumeService(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    @staticmethod
    def CreateAioVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/CreateAioVolume',
            backend__aio__pb2.CreateAioVolumeRequest.SerializeToString,
            backend__aio__pb2.AioVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAioVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/DeleteAioVolume',
            backend__aio__pb2.DeleteAioVolumeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAioVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/UpdateAioVolume',
            backend__aio__pb2.UpdateAioVolumeRequest.SerializeToString,
            backend__aio__pb2.AioVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAioVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/ListAioVolumes',
            backend__aio__pb2.ListAioVolumesRequest.SerializeToString,
            backend__aio__pb2.ListAioVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAioVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/GetAioVolume',
            backend__aio__pb2.GetAioVolumeRequest.SerializeToString,
            backend__aio__pb2.AioVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsAioVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioVolumeService/StatsAioVolume',
            backend__aio__pb2.StatsAioVolumeRequest.SerializeToString,
            backend__aio__pb2.StatsAioVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkethernet.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networkvlan_pb2 as networkvlan__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15networkethernet.proto\x12%opi_api.network.opinetcommon.v1alpha1\x1a\x11networkvlan.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xe5\x03\n\x0e\x45thernetConfig\x12%\n\x0bmac_address\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01R\nmacAddress\x12+\n\x0e\x61uto_negotiate\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\rautoNegotiate\x12>\n\x18standalone_link_training\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x16standaloneLinkTraining\x12[\n\x0b\x64uplex_mode\x18\x04 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.EthDuplexModeB\x04\xe2\x41\x01\x01R\nduplexMode\x12X\n\nport_speed\x18\x05 \x01(\x0e\x32\x33.opi_api.network.opinetcommon.v1alpha1.EthPortSpeedB\x04\xe2\x41\x01\x01R\tportSpeed\x12\x34\n\x13\x65nable_flow_control\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x11\x65nableFlowControl\x12R\n\x08\x66\x65\x63_mode\x18\x07 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.EthFecModeB\x04\xe2\x41\x01\x01R\x07\x66\x65\x63Mode\"\xf1\x02\n\x16\x45thernetInDistribution\x12,\n\x12rx_frames_octets64\x18\x01 \x01(\x04R\x10rxFramesOctets64\x12\x37\n\x18rx_frames_octets65_to127\x18\x02 \x01(\x04R\x15rxFramesOctets65To127\x12\x39\n\x19rx_frames_octets128_to255\x18\x03 \x01(\x04R\x16rxFramesOctets128To255\x12\x39\n\x19rx_frames_octets256_to511\x18\x04 \x01(\x04R\x16rxFramesOctets256To511\x12;\n\x1arx_frames_octets512_to1023\x18\x05 \x01(\x04R\x17rxFramesOctets512To1023\x12=\n\x1brx_frames_octets1024_to1518\x18\x06 \x01(\x04R\x18rxFramesOctets1024To1518\"\x8d\x08\n\x10\x45thernetCounters\x12\x31\n\x15rx_mac_control_frames\x18\x01 \x01(\x04R\x12rxMacControlFrames\x12-\n\x13rx_mac_pause_frames\x18\x02 \x01(\x04R\x10rxMacPauseFrames\x12,\n\x12rx_oversize_frames\x18\x03 \x01(\x04R\x10rxOversizeFrames\x12.\n\x13rx_undersize_frames\x18\x04 \x01(\x04R\x11rxUndersizeFrames\x12(\n\x10rx_jabber_frames\x18\x05 \x01(\x04R\x0erxJabberFrames\x12,\n\x12rx_fragment_frames\x18\x06 \x01(\x04R\x10rxFragmentFrames\x12.\n\x13rx_ieee8021q_frames\x18\x07 \x01(\x04R\x11rxIeee8021qFrames\x12\"\n\rrx_crc_errors\x18\x08 \x01(\x04R\x0brxCrcErrors\x12&\n\x0frx_block_errors\x18\t \x01(\x04R\rrxBlockErrors\x12*\n\x11rx_carrier_errors\x18\n \x01(\x04R\x0frxCarrierErrors\x12*\n\x11rx_interrupted_tx\x18\x0b \x01(\x04R\x0frxInterruptedTx\x12*\n\x11rx_late_collision\x18\x0c \x01(\x04R\x0frxLateCollision\x12\'\n\x10rx_mac_errors_rx\x18\r \x01(\x04R\rrxMacErrorsRx\x12.\n\x13rx_single_collision\x18\x0e \x01(\x04R\x11rxSingleCollision\x12&\n\x0frx_symbol_error\x18\x0f \x01(\x04R\rrxSymbolError\x12.\n\x13rx_maxsize_exceeded\x18\x10 \x01(\x04R\x11rxMaxsizeExceeded\x12\x33\n\x16out_mac_control_frames\x18\x11 \x01(\x04R\x13outMacControlFrames\x12/\n\x14out_mac_pause_frames\x18\x12 \x01(\x04R\x11outMacPauseFrames\x12\x30\n\x14out_ieee8021q_frames\x18\x13 \x01(\x04R\x12outIeee8021qFrames\x12)\n\x11out_mac_errors_tx\x18\x14 \x01(\x04R\x0eoutMacErrorsTx\x12m\n\x13\x65th_rx_distribution\x18\x15 \x01(\x0b\x32=.opi_api.network.opinetcommon.v1alpha1.EthernetInDistributionR\x11\x65thRxDistribution\"\x8a\x06\n\rEthernetState\x12\x1f\n\x0bmac_address\x18\x01 \x01(\tR\nmacAddress\x12%\n\x0e\x61uto_negotiate\x18\x02 \x01(\x08R\rautoNegotiate\x12\x38\n\x18standalone_link_training\x18\x03 \x01(\x08R\x16standaloneLinkTraining\x12U\n\x0b\x64uplex_mode\x18\x04 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.EthDuplexModeR\nduplexMode\x12R\n\nport_speed\x18\x05 \x01(\x0e\x32\x33.opi_api.network.opinetcommon.v1alpha1.EthPortSpeedR\tportSpeed\x12.\n\x13\x65nable_flow_control\x18\x06 \x01(\x08R\x11\x65nableFlowControl\x12L\n\x08\x66\x65\x63_mode\x18\x07 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.EthFecModeR\x07\x66\x65\x63Mode\x12$\n\x0ehw_mac_address\x18\x08 \x01(\tR\x0chwMacAddress\x12j\n\x16negotiated_duplex_mode\x18\t \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.EthDuplexModeR\x14negotiatedDuplexMode\x12g\n\x15negotiated_port_speed\x18\n \x01(\x0e\x32\x33.opi_api.network.opinetcommon.v1alpha1.EthPortSpeedR\x13negotiatedPortSpeed\x12S\n\x08\x63ounters\x18\x0b \x01(\x0b\x32\x37.opi_api.network.opinetcommon.v1alpha1.EthernetCountersR\x08\x63ounters\"\x83\x02\n\nEthernetIf\x12M\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.opi_api.network.opinetcommon.v1alpha1.EthernetConfigR\x06\x63onfig\x12J\n\x05state\x18\x02 \x01(\x0b\x32\x34.opi_api.network.opinetcommon.v1alpha1.EthernetStateR\x05state\x12Z\n\rswitched_vlan\x18\x03 \x01(\x0b\x32\x35.opi_api.network.opinetcommon.v1alpha1.VlanSwitchedIfR\x0cswitchedVlan*d\n\rEthDuplexMode\x12\x1f\n\x1b\x45TH_DUPLEX_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45TH_DUPLEX_MODE_FULL\x10\x01\x12\x18\n\x14\x45TH_DUPLEX_MODE_HALF\x10\x02*\xa0\x03\n\x0c\x45thPortSpeed\x12\x1e\n\x1a\x45TH_PORT_SPEED_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45TH_PORT_SPEED_10M\x10\x01\x12\x17\n\x13\x45TH_PORT_SPEED_100M\x10\x02\x12\x15\n\x11\x45TH_PORT_SPEED_1G\x10\x03\x12\x18\n\x14\x45TH_PORT_SPEED_2500M\x10\x04\x12\x15\n\x11\x45TH_PORT_SPEED_5G\x10\x05\x12\x16\n\x12\x45TH_PORT_SPEED_10G\x10\x06\x12\x16\n\x12\x45TH_PORT_SPEED_25G\x10\x07\x12\x16\n\x12\x45TH_PORT_SPEED_40G\x10\x08\x12\x16\n\x12\x45TH_PORT_SPEED_50G\x10\t\x12\x17\n\x13\x45TH_PORT_SPEED_100G\x10\n\x12\x17\n\x13\x45TH_PORT_SPEED_200G\x10\x0b\x12\x17\n\x13\x45TH_PORT_SPEED_400G\x10\x0c\x12\x17\n\x13\x45TH_PORT_SPEED_600G\x10\r\x12\x17\n\x13\x45TH_PORT_SPEED_800G\x10\x0e\x12\x1a\n\x16\x45TH_PORT_SPEED_UNKNOWN\x10\x0f*\xb0\x01\n\nEthFecMode\x12\x1c\n\x18\x45TH_FEC_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x45TH_FEC_MODE_FC\x10\x01\x12\x16\n\x12\x45TH_FEC_MODE_RS528\x10\x02\x12\x16\n\x12\x45TH_FEC_MODE_RS544\x10\x03\x12$\n ETH_FEC_MODE_RS544_2X_INTERLEAVE\x10\x04\x12\x19\n\x15\x45TH_FEC_MODE_DISABLED\x10\x05\x42\x83\x01\n%opi_api.network.opinetcommon.v1alpha1B\x14NetworkEthernetProtoP\x01ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkethernet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%opi_api.network.opinetcommon.v1alpha1B\024NetworkEthernetProtoP\001ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/go'
  _globals['_ETHERNETCONFIG'].fields_by_name['mac_address']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['mac_address']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['auto_negotiate']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['auto_negotiate']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['standalone_link_training']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['standalone_link_training']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['duplex_mode']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['duplex_mode']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['port_speed']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['port_speed']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['enable_flow_control']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['enable_flow_control']._serialized_options = b'\342A\001\001'
  _globals['_ETHERNETCONFIG'].fields_by_name['fec_mode']._options = None
  _globals['_ETHERNETCONFIG'].fields_by_name['fec_mode']._serialized_options = b'\342A\001\001'
  _globals['_ETHDUPLEXMODE']._serialized_start=3059
  _globals['_ETHDUPLEXMODE']._serialized_end=3159
  _globals['_ETHPORTSPEED']._serialized_start=3162
  _globals['_ETHPORTSPEED']._serialized_end=3578
  _globals['_ETHFECMODE']._serialized_start=3581
  _globals['_ETHFECMODE']._serialized_end=3757
  _globals['_ETHERNETCONFIG']._serialized_start=117
  _globals['_ETHERNETCONFIG']._serialized_end=602
  _globals['_ETHERNETINDISTRIBUTION']._serialized_start=605
  _globals['_ETHERNETINDISTRIBUTION']._serialized_end=974
  _globals['_ETHERNETCOUNTERS']._serialized_start=977
  _globals['_ETHERNETCOUNTERS']._serialized_end=2014
  _globals['_ETHERNETSTATE']._serialized_start=2017
  _globals['_ETHERNETSTATE']._serialized_end=2795
  _globals['_ETHERNETIF']._serialized_start=2798
  _globals['_ETHERNETIF']._serialized_end=3057
# @@protoc_insertion_point(module_scope)
